CesrVerificationException class

An exception thrown when the verification of CESR signature fails

Implemented types

Constructors

CesrVerificationException(String cause)
Exception constructor containing the description for the exception.

Properties

cause ↔ String
The description for the exception.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited